==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/DataSourceDataProviderSchemaChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DataSourceDataProviderSchemaChangedEventArgsDescription } from "./DataSourceDataProviderSchemaChangedEventArgsDescription";
/**
 * @hidden
 */
var DataSourceDataProviderSchemaChangedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(DataSourceDataProviderSchemaChangedEventArgsDescriptionMetadata, _super);
    function DataSourceDataProviderSchemaChangedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    DataSourceDataProviderSchemaChangedEventArgsDescriptionMetadata.b = function (a) {
        if (DataSourceDataProviderSchemaChangedEventArgsDescriptionMetadata.a == null) {
            DataSourceDataProviderSchemaChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            DataSourceDataProviderSchemaChangedEventArgsDescriptionMetadata.c(DataSourceDataProviderSchemaChangedEventArgsDescriptionMetadata.a);
        }
        if (a.j(DataSourceDataProviderSchemaChangedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(DataSourceDataProviderSchemaChangedEventArgsDescriptionMetadata.a);
    };
    DataSourceDataProviderSchemaChangedEventArgsDescriptionMetadata.c = function (a) {
    };
    DataSourceDataProviderSchemaChangedEventArgsDescriptionMetadata.d = function (a) {
        DataSourceDataProviderSchemaChangedEventArgsDescriptionMetadata.b(a);
        a.aa("DataSourceDataProviderSchemaChangedEventArgs", function () { return new DataSourceDataProviderSchemaChangedEventArgsDescription(); });
        a.z("DataSourceDataProviderSchemaChangedEventArgs", DataSourceDataProviderSchemaChangedEventArgsDescriptionMetadata.a);
    };
    DataSourceDataProviderSchemaChangedEventArgsDescriptionMetadata.$t = markType(DataSourceDataProviderSchemaChangedEventArgsDescriptionMetadata, 'DataSourceDataProviderSchemaChangedEventArgsDescriptionMetadata');
    DataSourceDataProviderSchemaChangedEventArgsDescriptionMetadata.a = null;
    return DataSourceDataProviderSchemaChangedEventArgsDescriptionMetadata;
}(Base));
export { DataSourceDataProviderSchemaChangedEventArgsDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/DataSourceDataProviderSchemaChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DataSourceDataProviderSchemaChangedEventArgsDescription } from "./DataSourceDataProviderSchemaChangedEventArgsDescription";
/**
 * @hidden
 */
var DataSourceDataProviderSchemaChangedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(DataSourceDataProviderSchemaChangedEventArgsDescriptionMetadata, _super);
    function DataSourceDataProviderSchemaChangedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    DataSourceDataProviderSchemaChangedEventArgsDescriptionMetadata.b = function (a) {
        if (DataSourceDataProviderSchemaChangedEventArgsDescriptionMetadata.a == null) {
            DataSourceDataProviderSchemaChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            DataSourceDataProviderSchemaChangedEventArgsDescriptionMetadata.c(DataSourceDataProviderSchemaChangedEventArgsDescriptionMetadata.a);
        }
        if (a.k(DataSourceDataProviderSchemaChangedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.aa(DataSourceDataProviderSchemaChangedEventArgsDescriptionMetadata.a);
    };
    DataSourceDataProviderSchemaChangedEventArgsDescriptionMetadata.c = function (a) {
    };
    DataSourceDataProviderSchemaChangedEventArgsDescriptionMetadata.d = function (a) {
        DataSourceDataProviderSchemaChangedEventArgsDescriptionMetadata.b(a);
        a.ac("DataSourceDataProviderSchemaChangedEventArgs", function () { return new DataSourceDataProviderSchemaChangedEventArgsDescription(); });
        a.ab("DataSourceDataProviderSchemaChangedEventArgs", DataSourceDataProviderSchemaChangedEventArgsDescriptionMetadata.a);
    };
    DataSourceDataProviderSchemaChangedEventArgsDescriptionMetadata.$t = markType(DataSourceDataProviderSchemaChangedEventArgsDescriptionMetadata, 'DataSourceDataProviderSchemaChangedEventArgsDescriptionMetadata');
    DataSourceDataProviderSchemaChangedEventArgsDescriptionMetadata.a = null;
    return DataSourceDataProviderSchemaChangedEventArgsDescriptionMetadata;
}(Base));
export { DataSourceDataProviderSchemaChangedEventArgsDescriptionMetadata };
